__all__ = ["corpora", "corpus", "nahuatl", "otomi"]

def test():
    return ('Test paquete elotl satisfactorio')
